=============
API Reference
=============



Normalization methods
=====================

.. currentmodule:: rnanorm

.. autosummary::
   :nosignatures:
   :toctree: generated/

   CPM
   FPKM
   TPM
   UQ
   CUF
   TMM
   CTF


Datasets
========

.. currentmodule:: rnanorm

.. autosummary::
   :nosignatures:
   :toctree: generated/

   datasets.load_toy_data
   datasets.load_gtex
